@@ -1,3 +1,13 @@
+# flake8: noqa
+
+__all__ = [
+    'ExtensionManager',
+    'EnabledExtensionManager',
+    'NamedExtensionManager',
+    'HookManager',
+    'DriverManager',
+]
+
 from .extension import ExtensionManager
 from .enabled import EnabledExtensionManager
 from .named import NamedExtensionManager
@@ -8,9 +18,6 @@ import logging
 
 # Configure a NullHandler for our log messages in case
 # the app we're used from does not set up logging.
-LOG = logging.getLogger(__name__)
-try:
-    LOG.addHandler(logging.NullHandler())
-except AttributeError:
-    # No NullHandler, probably python 2.6
-    pass
+LOG = logging.getLogger('stevedore')
+
+LOG.addHandler(logging.NullHandler())
