@@ -1,3 +1,15 @@
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
+
 """TestExtensionManager
 
 Extension manager used only for testing.
@@ -41,11 +53,11 @@ class TestExtensionManager(extension.ExtensionManager):
                  invoke_on_load=False,
                  invoke_args=(),
                  invoke_kwds={}):
-        super(TestExtensionManager, self).__init__(namespace,
-                                                   invoke_on_load,
-                                                   invoke_args,
-                                                   invoke_kwds,
-                                                   )
+        super().__init__(namespace,
+                         invoke_on_load,
+                         invoke_args,
+                         invoke_kwds,
+                         )
         self.extensions = extensions
         warnings.warn(
             'TestExtesionManager has been replaced by make_test_instance()',
